﻿using System;
using System.Drawing;

using MonoTouch.Foundation;
using MonoTouch.UIKit;
using System.Collections.Generic;
using Infragistics;

namespace IGScatterChartAnimationSampleCSharp
{
	public class ChartDataModel : NSObject
	{
		[MonoTouch.Foundation.Export("X")]
		public double X {get;set;}

		[MonoTouch.Foundation.Export("Y")]
		public double Y {get;set;}
	}

	public partial class IGScatterChartAnimationSampleCSharpViewController : UIViewController
	{
		static bool UserInterfaceIdiomIsPhone
		{
			get { return UIDevice.CurrentDevice.UserInterfaceIdiom == UIUserInterfaceIdiom.Phone; }
		}

		public IGScatterChartAnimationSampleCSharpViewController (IntPtr handle) : base (handle)
		{
		}

		public override void DidReceiveMemoryWarning ()
		{
			// Releases the view if it doesn't have a superview.
			base.DidReceiveMemoryWarning ();
			
			// Release any cached data, images, etc that aren't in use.
		}

		#region View lifecycle

		IGScatterSeriesDataSourceHelper _source;
		IGChartView _chart;
		ChartDataModel[] _data;
		IGScatterSeries _series;
		int numberOfPoints = 5;

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();

			//creating data
			_data = new ChartDataModel[numberOfPoints];
			for (int i = 0; i < numberOfPoints; i++) {
				_data[i] = new ChartDataModel{ X = i, Y = i };
			}

			_source = new IGScatterSeriesDataSourceHelper (_data, "X", "Y");

			//add chart to view
			_chart = new IGChartView (this.View.Frame);
			this.View.AddSubview (_chart);

			//add x and y axis
			IGNumericXAxis xAxis = new IGNumericXAxis ("xAxis");
			IGNumericYAxis yAxis = new IGNumericYAxis ("yAxis");
			xAxis.Minimum = 0;
			xAxis.Maximum = 100;
			yAxis.Minimum = 0;
			yAxis.Maximum = 100;

			_chart.AddAxis (xAxis);
			_chart.AddAxis (yAxis);

			//add series
			_series = new IGScatterSeries ("series");
			_series.XAxis = xAxis;
			_series.YAxis = yAxis;
			_series.TransitionDuration = 1f;
			_series.DataSource = _source;
			_chart.AddSeries (_series);

			NSTimer.CreateRepeatingScheduledTimer (1, this.HandleInput);
		}


		private void HandleInput ()
		{
			Random r = new Random ();
			int index = r.Next (0, numberOfPoints);

			ChartDataModel obj = _data [index];
			obj.X = r.Next(0,100);
			obj.Y = r.Next(0,100);

			_chart.UpdateItem (index, _source);
		}


		public override void ViewWillAppear (bool animated)
		{
			base.ViewWillAppear (animated);
		}

		public override void ViewDidAppear (bool animated)
		{
			base.ViewDidAppear (animated);
		}

		public override void ViewWillDisappear (bool animated)
		{
			base.ViewWillDisappear (animated);
		}

		public override void ViewDidDisappear (bool animated)
		{
			base.ViewDidDisappear (animated);
		}

		#endregion
	}
}

